package net.knarcraft.bookswithoutborders.command;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

/**
 * Command executor for the delete command
 */
public class CommandDelete implements CommandExecutor {

    private final BooksWithoutBorders booksWithoutBorders;

    public CommandDelete(BooksWithoutBorders booksWithoutBorders) {
        this.booksWithoutBorders = booksWithoutBorders;
    }

    @Override
    public boolean onCommand(CommandSender sender, Command command, String label, String[] args) {
        if (!(sender instanceof Player)) {
            BooksWithoutBorders.sendErrorMessage(sender, "This command can only be used by a player!");
            return false;
        }

        return deleteBook(sender, args, false);
    }

    /**
     * Deletes a book
     * @param sender <p>The sender trying to delete the book</p>
     * @param args <p>The arguments given</p>
     * @param deletePublic <p>Whether to delete a public book</p>
     * @return <p>True if the book was deleted successfully</p>
     */
    boolean deleteBook(CommandSender sender, String[] args, boolean deletePublic) {
        //List deletable files
        if (args.length == 0) {
            BooksWithoutBorders.loadList.put(sender.getName(), booksWithoutBorders.listFiles(sender, deletePublic, false));
            return true;
        }
        //Delete the file
        if (args.length == 1) {
            if (!BooksWithoutBorders.loadList.containsKey(sender.getName())) {
                BooksWithoutBorders.sendErrorMessage(sender, "You must first use /bwb delete to create a list of delete-able files!");
                return false;
            } else {
                if (!BooksWithoutBorders.loadList.get(sender.getName()).isEmpty()) {
                    booksWithoutBorders.deleteBook(sender, args[0], deletePublic);
                    return true;
                } else {
                    BooksWithoutBorders.sendErrorMessage(sender, "No files available to delete!");
                    return false;
                }
            }
        }
        BooksWithoutBorders.sendErrorMessage(sender, "Incorrect number of arguments for this command!");
        return false;
    }

}
